@@ -1,3 +1,4 @@
+import os
 from faulthandler import disable
 from math import floor
 from turtle import color
@@ -33,6 +34,7 @@ from ..utilities.string_tools import string_html, units_html
 def make_dashboard():
     app = dash.Dash(
         __name__,
+        assets_url_path="merph/app/assets",
         external_stylesheets=[
             dbc.themes.BOOTSTRAP,
             dbc.icons.FONT_AWESOME,
@@ -1383,13 +1385,28 @@ def make_dashboard():
         tickvals = np.arange(-6, int(np.ceil(np.nanmax(bayes_posterior["logp"]))) + 1)
         ticktext = ["10<sup>" + str(x) + "</sup>" for x in tickvals]
 
+        color_start = -5 if xvar == "H" else -7
+        color_end = 1 if xvar == "H" else 2
+        color_steps = color_end - color_start
+        # clip_low = np.where(bayes_posterior["logp"] < color_start)
+        # bayes_posterior["logp"][clip_low] = np.NaN
+
+        # colorscale = px.colors.sequential.PuBu
+        colorscale = px.colors.sequential.Purpor
+        # colorscale[0] = colorscale[0].replace("rgb", "rgba")
+        # colorscale[0] = colorscale[0].replace(")", ",0)")
+        colorscale[0] = "rgba(255,247,251,0)"
+
+        print(colorscale)
+
         cntr_fig = go.Figure(
             data=go.Contour(
                 z=bayes_posterior["logp"],
                 x=bayes_posterior["Q"],  # horizontal axis
                 y=bayes_posterior["H"],  # vertical axis
                 customdata=bayes_posterior["p_str"],
-                colorscale="BuPu",
+                # colorscale="BuPu",
+                colorscale=colorscale,
                 contours=dict(
                     start=-5 if xvar == "H" else -7,
                     end=1 if xvar == "H" else 2,
